==> humanLLMappings_1.8.1.tar.gz: humanLLMappings/man/humanLLMappingsLL2GO.Rd <==
\name{humanLLMappingsLL2GO}
\alias{humanLLMappingsLL2GO}
\title{An annotation data file that maps LocusLink identifiers to Gene
  Ontology identifiers} 
\description{
  humanLLMappingsLL2GO maps LocusLink ids to Gene Ontology (GO) ids
  representing functions of the products of genes correspinding to the
  LocusLink ids 
}
\details{
  This is an environment object containing key and value pairs. Keys are
  LocusLink ids and values are GO ids. Values are vectors of length 1 or
  more depending on whether a LocusLink id can be mapped to one or more
  Gene Ontology ids. Names of values are evidence code.

  The evidence codes in use include:
  
  IMP: inferred from mutant phenotype  
  IGI: inferred from genetic interaction
  IPI: inferred from physical interaction  
  ISS: inferred from sequence similarity 
  IDA: inferred from direct assay  
  IEP: inferred from expression pattern  
  IEA: inferred from electronic annotation  
  TAS: traceable author statement  
  NAS: non-traceable author statement  
  ND: no biological data avai

  Mappings were derived from data provided by:

  Entrez Gene: Not available
  
  Package built: Thu May 12 12:18:56 2005
}
\references{
\url{ftp://ftp.ncbi.nih.gov/refseq/LocusLink/LL_tmpl.gz}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanLLMappingsLL2GO)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[[1]]
		# Get the values  for a few keys
		if(length(xx) >= 3){
			xx[1:3]
		}
	}
}
\keyword{datasets}

==> humanLLMappings_1.10.0.tar.gz: humanLLMappings/man/humanLLMappingsLL2GO.Rd <==
\name{humanLLMappingsLL2GO}
\alias{humanLLMappingsLL2GO}
\title{An annotation data file that maps LocusLink identifiers to Gene
  Ontology identifiers} 
\description{
  humanLLMappingsLL2GO maps LocusLink ids to Gene Ontology (GO) ids
  representing functions of the products of genes correspinding to the
  LocusLink ids 
}
\details{
  This is an environment object containing key and value pairs. Keys are
  LocusLink ids and values are GO ids. Values are vectors of length 1 or
  more depending on whether a LocusLink id can be mapped to one or more
  Gene Ontology ids. Names of values are evidence code.

  The evidence codes in use include:
  
  IMP: inferred from mutant phenotype  
  IGI: inferred from genetic interaction
  IPI: inferred from physical interaction  
  ISS: inferred from sequence similarity 
  IDA: inferred from direct assay  
  IEP: inferred from expression pattern  
  IEA: inferred from electronic annotation  
  TAS: traceable author statement  
  NAS: non-traceable author statement  
  ND: no biological data avai

  Mappings were derived from data provided by:

  Entrez Gene: Not available
  
  Package built: Tue Oct  4 19:17:05 2005
}
\references{
\url{ftp://ftp.ncbi.nih.gov/refseq/LocusLink/LL_tmpl.gz}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(humanLLMappingsLL2GO)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[[1]]
		# Get the values  for a few keys
		if(length(xx) >= 3){
			xx[1:3]
		}
	}
}
\keyword{datasets}
